@@ -13,9 +13,7 @@ test.use({
 });
 
 test('Announcements requires user agreement', async ({ page }) => {
-  const notifications = await page.evaluate(() => {
-    return (window.jupyterapp as any).notificationManager.notifications;
-  });
+  const notifications = await page.notifications;
 
   expect(notifications).toHaveLength(1);
   expect(notifications[0].message).toEqual(
@@ -74,9 +72,7 @@ test.describe('Update available', () => {
 
     await page.goto();
 
-    const notifications = await page.evaluate(() => {
-      return (window.jupyterapp as any).notificationManager.notifications;
-    });
+    const notifications = await page.notifications;
 
     const updates = notifications.filter(n =>
       n.options?.data?.tags?.includes('update')
@@ -100,9 +96,7 @@ test.describe('Update available', () => {
 
     await page.goto();
 
-    const notifications = await page.evaluate(() => {
-      return (window.jupyterapp as any).notificationManager.notifications;
-    });
+    const notifications = await page.notifications;
 
     expect(
       notifications.filter(n => n.options?.data?.tags?.includes('update'))
@@ -129,9 +123,7 @@ test.describe('Update available', () => {
 
     await page.goto();
 
-    const notifications = await page.evaluate(() => {
-      return (window.jupyterapp as any).notificationManager.notifications;
-    });
+    const notifications = await page.notifications;
     expect(
       notifications.filter(n => n.options?.data?.tags?.includes('update'))
     ).toHaveLength(0);
@@ -193,9 +185,7 @@ test.describe('Fetch news', () => {
 
     await page.goto();
 
-    const notifications = await page.evaluate(() => {
-      return (window.jupyterapp as any).notificationManager.notifications;
-    });
+    const notifications = await page.notifications;
 
     const news = notifications.filter(n =>
       n.options?.data?.tags?.includes('news')
@@ -222,9 +212,7 @@ test.describe('Fetch news', () => {
 
     await page.goto();
 
-    const notifications = await page.evaluate(() => {
-      return (window.jupyterapp as any).notificationManager.notifications;
-    });
+    const notifications = await page.notifications;
 
     const news = notifications.filter(n =>
       n.options?.data?.tags?.includes('news')
@@ -251,9 +239,7 @@ test.describe('Fetch news', () => {
 
     await page.goto();
 
-    const notifications = await page.evaluate(() => {
-      return (window.jupyterapp as any).notificationManager.notifications;
-    });
+    const notifications = await page.notifications;
 
     const news = notifications.filter(n =>
       n.options?.data?.tags?.includes('news')
